@@ -2,8 +2,9 @@
 // SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
 #include "windowsWalker.h"
-
+#include <QDebug>
 #include <QScopeGuard>
+#include <QString>
 
 WindowsWalker::WindowsWalker(const QByteArray &path)
     : m_path(path)
